.. :changelog:

History
-------

0.1.2 (2017-04-07)
++++++++++++++++++
* Add support for boto3 and multiprocessing instead of gevent
* Moved backends to a submodule (please change your setting variables `STATICFILES_STORAGE` and `DEFAULT_FILE_STORAGE`)

0.1.1 (2016-08-08)
++++++++++++++++++

* Rather use `django-storages` than the deprecated fork from `django-storages-redux`.


0.1.0 (2016-05-19)
++++++++++++++++++

* First release on PyPI.
